==> hibiscus.js-1.2.2.tgz: package/message/message-container.component.js <==
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Component, Inject, Optional } from '@angular/core';
import { MESSAGE_CONFIG, MESSAGE_DEFAULT_CONFIG } from './message-config';
var MessageContainerComponent = /** @class */ (function () {
    function MessageContainerComponent(defaultConfig, config) {
        this.messages = [];
        this.config = {};
        this.setConfig(__assign({}, defaultConfig, config));
    }
    MessageContainerComponent.prototype.setConfig = function (config) {
        this.config = __assign({}, this.config, config);
    };
    // Create a new message
    // Create a new message
    MessageContainerComponent.prototype.createMessage = 
    // Create a new message
    function (message) {
        if (this.messages.length >= this.config.hiMaxStack) {
            this.messages.splice(0, 1);
        }
        message.options = this._mergeMessageOptions(message.options);
        this.messages.push(message);
    };
    // Remove a message by messageId
    // Remove a message by messageId
    MessageContainerComponent.prototype.removeMessage = 
    // Remove a message by messageId
    function (messageId) {
        var _this = this;
        this.messages.some(function (message, index) {
            if (message.messageId === messageId) {
                _this.messages.splice(index, 1);
                return true;
            }
        });
    };
    // Remove all messages
    // Remove all messages
    MessageContainerComponent.prototype.removeMessageAll = 
    // Remove all messages
    function () {
        this.messages = [];
    };
    // Merge default options and cutom message options
    // Merge default options and cutom message options
    MessageContainerComponent.prototype._mergeMessageOptions = 
    // Merge default options and cutom message options
    function (options) {
        var defaultOptions = {
            hiDuration: this.config.hiDuration,
            hiAnimate: this.config.hiAnimate,
            hiPauseOnHover: this.config.hiPauseOnHover
        };
        return __assign({}, defaultOptions, options);
    };
    MessageContainerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'hi-message-container',
                    preserveWhitespaces: false,
                    template: "\n    <div class=\"hi-message\"><hi-message *ngFor=\"let message of messages; let i = index\" [hiMessage]=\"message\" [hiIndex]=\"i\"></hi-message></div>\n  "
                },] },
    ];
    /** @nocollapse */
    MessageContainerComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGE_DEFAULT_CONFIG,] },] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGE_CONFIG,] },] },
    ]; };
    return MessageContainerComponent;
}());
export { MessageContainerComponent };

==> hibiscus.js-1.2.3.tgz: package/message/message-container.component.js <==
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
import { Component, Inject, Optional } from '@angular/core';
import { MESSAGE_CONFIG, MESSAGE_DEFAULT_CONFIG } from './message-config';
var MessageContainerComponent = (function () {
    function MessageContainerComponent(defaultConfig, config) {
        this.messages = [];
        this.config = {};
        this.setConfig(__assign({}, defaultConfig, config));
    }
    MessageContainerComponent.prototype.setConfig = function (config) {
        this.config = __assign({}, this.config, config);
    };
    MessageContainerComponent.prototype.createMessage = function (message) {
        if (this.messages.length >= this.config.hiMaxStack) {
            this.messages.splice(0, 1);
        }
        message.options = this._mergeMessageOptions(message.options);
        this.messages.push(message);
    };
    MessageContainerComponent.prototype.removeMessage = function (messageId) {
        var _this = this;
        this.messages.some(function (message, index) {
            if (message.messageId === messageId) {
                _this.messages.splice(index, 1);
                return true;
            }
        });
    };
    MessageContainerComponent.prototype.removeMessageAll = function () {
        this.messages = [];
    };
    MessageContainerComponent.prototype._mergeMessageOptions = function (options) {
        var defaultOptions = {
            hiDuration: this.config.hiDuration,
            hiAnimate: this.config.hiAnimate,
            hiPauseOnHover: this.config.hiPauseOnHover
        };
        return __assign({}, defaultOptions, options);
    };
    MessageContainerComponent.decorators = [
        { type: Component, args: [{
                    selector: 'hi-message-container',
                    preserveWhitespaces: false,
                    template: "\n    <div class=\"hi-message\"><hi-message *ngFor=\"let message of messages; let i = index\" [hiMessage]=\"message\" [hiIndex]=\"i\"></hi-message></div>\n  "
                },] },
    ];
    MessageContainerComponent.ctorParameters = function () { return [
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGE_DEFAULT_CONFIG,] },] },
        { type: undefined, decorators: [{ type: Optional }, { type: Inject, args: [MESSAGE_CONFIG,] },] },
    ]; };
    return MessageContainerComponent;
}());
export { MessageContainerComponent };
